@@ -193,8 +193,4 @@ if (!isGeneric("plotKML")){
   setGeneric("plotKML", function(obj, ...){standardGeneric("plotKML")})
  }
  
-if (!isGeneric("count")){
-  setGeneric("count", function(x, ...){standardGeneric("count")})
- }
-
 # end of script;
\ No newline at end of file
