@@ -10,13 +10,11 @@ kml_layer.STIDF <- function(
   ...
   ){
 
-  require(xts)
   # Format the time slot for writing to KML:
   if(all(dtime==0)) {  
     TimeSpan.begin = format(time(obj@time), "%Y-%m-%dT%H:%M:%SZ")
     TimeSpan.end = TimeSpan.begin
-  }
-  else {
+  } else {
     if(length(obj@time)>1&!nzchar(dtime)){
       period <- periodicity(obj@time) # estimate the time support (if not indicated)
       dtime <- period$frequency
@@ -48,4 +46,4 @@ kml_layer.STIDF <- function(
 
 setMethod("kml_layer", "STIDF", kml_layer.STIDF)
 
-# end of script;
\ No newline at end of file
+# end of script;
